==> gdm-2.4.2.96.tar.bz2: gdm-2.4.2.96/gui/gdmsetup-strings.c <==
/*
 * Soubor s přeložitelnými řetězci generovaný programem Glade.
 * Přidejte tento soubor do POTFILES.in svého projektu.
 * NEPŘEKLÁDEJTE JEJ jako součást své aplikace.
 */

gchar *s = N_("Login Screen Setup");
gchar *s = N_("<b>Greeter</b>");
gchar *s = N_("    ");
gchar *s = N_("L_ocal: ");
gchar *s = N_("_Remote: ");
gchar *s = N_("_Welcome string: ");
gchar *s = N_("Re_mote welcome string: ");
gchar *s = N_("Standard greeter");
gchar *s = N_("Graphical greeter");
gchar *s = N_("Standard greeter");
gchar *s = N_("Graphical greeter");
gchar *s = N_("String to be shown in the greeter as welcome.  You can insert %n in here and it will be replaced by the name of your computer.");
gchar *s = N_("*");
gchar *s = N_("String to be shown in the greeter for people logging in remotely with XDMCP.  You can insert %n in here and it will be replaced by the name of your computer.");
gchar *s = N_("*");
gchar *s = N_("Always use 24 hour cloc_k format");
gchar *s = N_("<b>Automatic Login</b>");
gchar *s = N_("    ");
gchar *s = N_("_Automatic login username:");
gchar *s = N_("*");
gchar *s = N_("_Login a user automatically on first bootup");
gchar *s = N_("<b>Timed Login</b>");
gchar *s = N_("    ");
gchar *s = N_("Timed login us_ername:");
gchar *s = N_("_Seconds before login:");
gchar *s = N_("*");
gchar *s = N_("Login a user automa_tically after a specified number of seconds");
gchar *s = N_("General");
gchar *s = N_("<b>Logo</b>");
gchar *s = N_("    ");
gchar *s = N_("*");
gchar *s = N_("<b>Miscellaneous</b>");
gchar *s = N_("    ");
gchar *s = N_("Show choosable user images (_face browser)");
gchar *s = N_("<b>Background</b>");
gchar *s = N_("    ");
gchar *s = N_("_No background");
gchar *s = N_("_Image");
gchar *s = N_("Co_lor");
gchar *s = N_("_Scale background image to fit");
gchar *s = N_("*");
gchar *s = N_("_Only color on remote displays");
gchar *s = N_("_Background color: ");
gchar *s = N_("Pick a color");
gchar *s = N_("Standard greeter");
gchar *s = N_("<b>Preview:</b>");
gchar *s = N_("No screenshot available");
gchar *s = N_("<b>Description:</b>");
gchar *s = N_("<b>Copyright:</b>");
gchar *s = N_("<b>Author:</b>");
gchar *s = N_("description\n"
              "widget");
gchar *s = N_("author");
gchar *s = N_("copyright");
gchar *s = N_("_Install new theme");
gchar *s = N_("_Delete theme");
gchar *s = N_("Graphical greeter");
gchar *s = N_("<b>Options</b>");
gchar *s = N_("    ");
gchar *s = N_("Allow _root to login with GDM");
gchar *s = N_("Allow root to login r_emotely with GDM");
gchar *s = N_("Allow remote _timed logins");
gchar *s = N_("Show the \"Actions\" menu (formerly known as the \"System\" menu).  If not set, none of the system commands will be available (this includes reboot, shutdown, configure, chooser)");
gchar *s = N_("Show _actions menu");
gchar *s = N_("Allow c_onfiguration from the login screen");
gchar *s = N_("Allo_w running XDMCP chooser from the login screen");
gchar *s = N_("Always disallow TCP connections to _X server");
gchar *s = N_("Retry _delay (seconds) :");
gchar *s = N_("Security");
gchar *s = N_("No XDMCP support in the binary.  To enable XDMCP support you must recompile GDM with the XDMCP libraries.");
gchar *s = N_("<b>Enable _XDMCP</b>");
gchar *s = N_("    ");
gchar *s = N_("Honour _indirect requests");
gchar *s = N_("Listen on _UDP port: ");
gchar *s = N_("Maximum _pending requests:");
gchar *s = N_("Max p_ending indirect requests:");
gchar *s = N_("Maximum _remote sessions:");
gchar *s = N_("Maximum _wait time:");
gchar *s = N_("Maximum indirect w_ait time:");
gchar *s = N_("Displays per _host:");
gchar *s = N_("Pin_g interval (seconds):");
gchar *s = N_("Ping interval (seconds):");
gchar *s = N_("XDMCP");

==> gdm-2.4.2.97.tar.bz2: gdm-2.4.2.97/gui/gdmsetup-strings.c <==
/*
 * Soubor s přeložitelnými řetězci generovaný programem Glade.
 * Přidejte tento soubor do souboru vašeho projektu POTFILES.in.
 * NEPŘEKLÁDEJTE JEJ jako součást vaší aplikace.
 */

gchar *s = N_("Login Screen Setup");
gchar *s = N_("Greeter");
gchar *s = N_("    ");
gchar *s = N_("L_ocal: ");
gchar *s = N_("_Remote: ");
gchar *s = N_("_Welcome string: ");
gchar *s = N_("Re_mote welcome string: ");
gchar *s = N_("Standard greeter");
gchar *s = N_("Graphical greeter");
gchar *s = N_("Standard greeter");
gchar *s = N_("Graphical greeter");
gchar *s = N_("String to be shown in the greeter as welcome.  You can insert %n in here and it will be replaced by the name of your computer.");
gchar *s = N_("*");
gchar *s = N_("String to be shown in the greeter for people logging in remotely with XDMCP.  You can insert %n in here and it will be replaced by the name of your computer.");
gchar *s = N_("*");
gchar *s = N_("Always use 24 hour cloc_k format");
gchar *s = N_("Automatic Login");
gchar *s = N_("    ");
gchar *s = N_("_Automatic login username:");
gchar *s = N_("*");
gchar *s = N_("_Login a user automatically on first bootup");
gchar *s = N_("Timed Login");
gchar *s = N_("    ");
gchar *s = N_("Timed login us_ername:");
gchar *s = N_("_Seconds before login:");
gchar *s = N_("*");
gchar *s = N_("Login a user automa_tically after a specified number of seconds");
gchar *s = N_("General");
gchar *s = N_("Logo");
gchar *s = N_("    ");
gchar *s = N_("*");
gchar *s = N_("Miscellaneous");
gchar *s = N_("    ");
gchar *s = N_("Show choosable user images (_face browser)");
gchar *s = N_("Background");
gchar *s = N_("    ");
gchar *s = N_("_No background");
gchar *s = N_("_Image");
gchar *s = N_("Co_lor");
gchar *s = N_("_Scale background image to fit");
gchar *s = N_("*");
gchar *s = N_("_Only color on remote displays");
gchar *s = N_("_Background color: ");
gchar *s = N_("Pick a color");
gchar *s = N_("Standard greeter");
gchar *s = N_("Preview:");
gchar *s = N_("No screenshot available");
gchar *s = N_("Description:");
gchar *s = N_("Copyright:");
gchar *s = N_("Author:");
gchar *s = N_("description\n"
              "widget");
gchar *s = N_("author");
gchar *s = N_("copyright");
gchar *s = N_("_Install new theme");
gchar *s = N_("_Delete theme");
gchar *s = N_("Graphical greeter");
gchar *s = N_("Options");
gchar *s = N_("    ");
gchar *s = N_("Allow _root to login with GDM");
gchar *s = N_("Allow root to login r_emotely with GDM");
gchar *s = N_("Allow remote _timed logins");
gchar *s = N_("Show the \"Actions\" menu (formerly known as the \"System\" menu).  If not set, none of the system commands will be available (this includes reboot, shutdown, configure, chooser)");
gchar *s = N_("Show _actions menu");
gchar *s = N_("Allow c_onfiguration from the login screen");
gchar *s = N_("Allo_w running XDMCP chooser from the login screen");
gchar *s = N_("Always disallow TCP connections to _X server (disables all remote connections)");
gchar *s = N_("Retry _delay (seconds) :");
gchar *s = N_("Security");
gchar *s = N_("No XDMCP support in the binary.  To enable XDMCP support you must recompile GDM with the XDMCP libraries.");
gchar *s = N_("Enable _XDMCP");
gchar *s = N_("    ");
gchar *s = N_("Honour _indirect requests");
gchar *s = N_("Listen on _UDP port: ");
gchar *s = N_("Maximum _pending requests:");
gchar *s = N_("Max p_ending indirect requests:");
gchar *s = N_("Maximum _remote sessions:");
gchar *s = N_("Maximum _wait time:");
gchar *s = N_("Maximum indirect w_ait time:");
gchar *s = N_("Displays per _host:");
gchar *s = N_("Pin_g interval (seconds):");
gchar *s = N_("Ping interval (seconds):");
gchar *s = N_("XDMCP");
